% 
% CECILIA2050 - Scenarios for 2050 for a 2-degrees world
% Copyright (c) 2014 Instituute of Environmental Sciences (CML) Universiteit Leiden
%  
% This program is free software; you can redistribute it and/or modify it under
% the terms of the GNU General Public License as published by the Free Software
% Foundation; either version 2 of the License, or (at your option) any later
% version.
%  
% This program is distributed in the hope that it will be useful, but WITHOUT
% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
% FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
% details.
%  
% You should have received a copy of the GNU General Public License along with
% this program; if not, write to the Free Software Foundation, Inc., 51
% Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
% 

%
% The electricity mix change implemented in step2a strongly reduces the
% amount of electricity generated by coal power plants while increasing
% the contribution of gas fired and nuclear power plants. We therefore
% expect that supply from the coal mining sector decreases and from the
% natural gas extraction & gas distribution services increases. 
% In this script we calculate those changes
%


    % program settings
    clear all;
    more off;
    dim = 4;
    utildir = strcat(pwd(),'/../util/');
    addpath(utildir);
    coalIdx = [18, 147, 276, 405];
    oilIdx = [19, 148, 277, 406];
    gasIdx = [20, 149, 278, 407];
    elecIdx = [84, 85, 86, 87, 88, 89];
    
    
    

    % read files   
    Voriginal = dlmread('../step1/Vend.txt', '\t');
    Vnew = dlmread('Vend.txt', '\t');
    Moriginal = dlmread('../step1/Mend.txt', '\t');
    Mnew = dlmread('Mend.txt', '\t');
      
    % total product supply
    q2Original = tpom(Voriginal);
    q2New = tpom(Vnew);
    
    % change in supply
    coalOriginal = q2Original(coalIdx);
    coalNew = q2New(coalIdx);
    oilOriginal = q2Original(oilIdx);
    oilNew = q2New(oilIdx);
    gasOriginal = q2Original(gasIdx);
    gasNew = q2New(gasIdx);
    
    % percentage changes
    coalChange = 100 * (coalNew - coalOriginal) ./ coalOriginal
    gasChange = 100 * (gasNew - gasOriginal) ./ gasOriginal
    
    
    % does the changes in coal mining and gas extraction lead
    % to changes in emissions from these sectors
    coalCO2Original = transpose(Moriginal(1, coalIdx));
    coalCO2New = transpose(Mnew(1, coalIdx));
    gasCO2Original = transpose(Moriginal(1, gasIdx));
    gasCO2New = transpose(Mnew(1, gasIdx));
    
    
    % percentage changes
    coalCO2Change = 100 * (coalCO2New - coalCO2Original) ./ coalCO2Original
    gasCO2Change = 100 * (gasCO2New - gasCO2Original) ./ gasCO2Original
    
    
    % calculate changes in direct CO2 emissions from the electricity
    % sector 
    for i =0:3
      idx0 = 84 + (i * 129);
      idx1 = 89 + (i * 129);
      CO2Original = sum(Moriginal(1, idx0:idx1));
      CO2New = sum(Mnew(1, idx0:idx1));
      elecCO2Change(i+1,1) = 100 * (CO2New - CO2Original) ./ CO2Original;
    endfor
 
    elecCO2Change